@@ -20,6 +20,29 @@ epoch_tz = epoch.replace(tzinfo=timezone.utc)
 SecondsTimedelta = Union[int, float, timedelta]
 
 
+def import_string(dotted_path: str) -> Any:
+    """
+    Stolen approximately from Django. Import a dotted module path and return
+    the attribute/class designated by the last name in the path.
+    Raise ImportError if the import fails.
+    """
+    from importlib import import_module
+
+    try:
+        module_path, class_name = dotted_path.strip(' ').rsplit('.', 1)
+    except ValueError as e:
+        raise ImportError(
+            f'"{dotted_path}" doesn\'t look like a module path') from e
+
+    module = import_module(module_path)
+    try:
+        return getattr(module, class_name)
+    except AttributeError as e:
+        raise ImportError(
+            f'Module "{module_path}" does not define a "{class_name}" '
+            f'attribute') from e
+
+
 def as_int(f: float) -> int:
     return int(round(f))
 
